@@ -3,7 +3,7 @@ package App::Maisha::Plugin::Twitter;
 use strict;
 use warnings;
 
-my $VERSION = '0.01';
+my $VERSION = '0.02';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -44,6 +44,18 @@ sub api_update
     $self->api->update(@_);
 }
 
+sub api_user
+{
+    my $self = shift;
+    $self->api->show_user(@_);
+}
+
+sub api_user_timeline
+{
+    my $self = shift;
+    $self->api->user_timeline(@_);
+}
+
 sub api_friends
 {
     my $self = shift;
@@ -92,6 +104,18 @@ sub api_direct_messages_from
     $self->api->sent_direct_messages();
 }
 
+sub api_follow
+{
+    my $self = shift;
+    $self->api->create_friend(@_);
+}
+
+sub api_unfollow
+{
+    my $self = shift;
+    $self->api->destroy_friend(@_);
+}
+
 1;
 
 __END__
@@ -103,7 +127,7 @@ App::Maisha::Plugin::Twitter - Maisha interface to Twitter
 =head1 SYNOPSIS
 
    maisha
-   maisha> use Twitter <username> <password>
+   maisha> use Twitter
    use ok
 
 =head1 DESCRIPTION
@@ -137,6 +161,14 @@ The API methods are used to interface to with the Twitter API.
 
 =over 4
 
+=item * api_follow
+
+=item * api_unfollow
+
+=item * api_user
+
+=item * api_user_timeline
+
 =item * api_friends
 
 =item * api_friends_timeline
